import requests
from bs4 import BeautifulSoup
import json
import os
import asyncio
import math

class FLClient:
    def __init__(self, api_key):
        self.api_key = api_key
    def auth(self):
        if not all((self.api_key)):
            raise ValueError("API key must be specified.")
        Api_info = f"https://api.filelions.com/api/account/info?key={self.api_key}"
        try:
            response = requests.get(Api_info)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = response.json()
            a_api = json_data["status"]
            if int(a_api) == 200:
                print("You are authorised")
            else:
                print("Unsuccessful ! Check credentials.")
        except Exception as e:
            print(e)

    def upload_video(self, file_path, folder_id=13026):
        Main_API = f"https://api.filelions.com/api/upload/server?key={self.api_key}"
        try:
            response = requests.get(Main_API)
            response.raise_for_status()  # Raise an exception if the request was not successful
            json_data = response.json()
            temp_api = json_data["result"]
            print("Temp URL:" + temp_api)
            data = {
                'key': str(self.api_key),
                'fld_id': folder_id
            }
            files = {'file': open(file_path, 'rb')}
            response = requests.post(temp_api, data=data, files=files)
            response.raise_for_status()
            
            data_f = response.json()
            filecodes = extract_filecodes_from_json(data_f)
            for filecode in filecodes:
                print(filecode)
            return filecodes[0]
        except requests.exceptions.RequestException as e:
            print("Request Exception:", e)
            return f"Error {e}"


def extract_filecodes_from_json(response_json, base_url="https://filelions.online/d/"):
    try:
        # Parse the JSON string
        data = response_json

        # Extract the "filecode" values and prepend the base_url
        filecodes = [base_url + file['filecode'] for file in data['files']]

        return filecodes
    except json.JSONDecodeError as e:
        print(f"Error parsing JSON: {e}")
        return []


# from heartloglost import FLClient as FL
# FL.auth(api_key)
# FL.upload_video(file_path, folder_id=13026)